# This file is part of pybliographer
# 
# Copyright (C) 1998,1999,2000 Frederic GOBRY
# Email : gobry@idiap.ch
# 	   
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2 
# of the License, or (at your option) any later version.
#   
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details. 
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# 
# $Id: __init__.py,v 1.1.1.1.2.2 2000/08/03 11:46:32 fredgo Exp $

# Perform the first initialisation of Gnome, so that the options passed to the script
# are not passed to Gnome

import sys

sys.argv = sys.argv [:2] + ['--'] + sys.argv [2:]

# correctly identify the program
import gnome
from Pyblio import version

gnome.app_id      = 'Pybliographic'
gnome.app_version = version.version

# import the GUI
import gnome.ui

# clean up our garbage
sys.argv = sys.argv [:2] + sys.argv [3:]

del sys, gnome


